pub struct SupergroupFullInfo {Show 14 fields
pub description: String,
pub member_count: i32,
pub administrator_count: i32,
pub restricted_count: i32,
pub banned_count: i32,
pub can_get_members: bool,
pub can_set_username: bool,
pub can_set_sticker_set: bool,
pub is_all_history_available: bool,
pub sticker_set_id: i64,
pub invite_link: String,
pub pinned_message_id: i64,
pub upgraded_from_basic_group_id: i32,
pub upgraded_from_max_message_id: i64,
}Expand description
Contains full information about a supergroup or channel
Fields
description: StringSupergroup or channel description
member_count: i32Number of members in the supergroup or channel; 0 if unknown
administrator_count: i32Number of privileged users in the supergroup or channel; 0 if unknown
restricted_count: i32Number of restricted users in the supergroup; 0 if unknown
banned_count: i32Number of users banned from chat; 0 if unknown
can_get_members: boolTrue, if members of the chat can be retrieved
can_set_username: boolTrue, if the chat can be made public
can_set_sticker_set: boolTrue, if the supergroup sticker set can be changed
is_all_history_available: boolTrue, if new chat members will have access to old messages. In public supergroups and both public and private channels, old messages are always available, so this option affects only private supergroups. The value of this field is only available for chat administrators
sticker_set_id: i64Identifier of the supergroup sticker set; 0 if none
invite_link: StringInvite link for this chat
pinned_message_id: i64Identifier of the pinned message in the chat; 0 if none
upgraded_from_basic_group_id: i32Identifier of the basic group from which supergroup was upgraded; 0 if none
upgraded_from_max_message_id: i64Identifier of the last message in the basic group from which supergroup was upgraded; 0 if none